@@ -27,11 +27,21 @@
 #include <KLocalizedString>
 
 #include <QDebug>
+#include <QtPlugin>
 
 Q_LOGGING_CATEGORY(KDECONNECT_KIO, "kdeconnect.kio")
 
-extern "C" int Q_DECL_EXPORT kdemain(int argc, char **argv)
+class KIOPluginForMetaData : public QObject
 {
+    Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.kde.kio.slave.kdeconnect" FILE "kdeconnect.json")
+};
+
+extern "C" int Q_DECL_EXPORT kdemain(int argc, char** argv)
+{
+    QCoreApplication app(argc, argv);
+    app.setApplicationName(QStringLiteral("kio_kdeconnect"));
+    
     if (argc != 4) {
         fprintf(stderr, "Usage: kio_kdeconnect protocol pool app\n");
         exit(-1);
@@ -72,7 +82,7 @@ bool handleDBusError(QDBusReply<T>& reply, KIO::SlaveBase* slave)
     return false;
 }
 
-KioKdeconnect::KioKdeconnect(const QByteArray &pool, const QByteArray &app)
+KioKdeconnect::KioKdeconnect(const QByteArray& pool, const QByteArray& app)
     : SlaveBase("kdeconnect", pool, app),
     m_dbusInterface(new DaemonDbusInterface(this))
 {
@@ -84,9 +94,9 @@ void KioKdeconnect::listAllDevices()
     infoMessage(i18n("Listing devices..."));
 
     //TODO: Change to all devices and show different icons for connected and disconnected?
-    QStringList devices = m_dbusInterface->devices(true, true);
+    const QStringList devices = m_dbusInterface->devices(true, true);
 
-    Q_FOREACH(const QString& deviceId, devices) {
+    for (const QString& deviceId : devices) {
 
         DeviceDbusInterface interface(deviceId);
 
@@ -118,13 +128,13 @@ void KioKdeconnect::listAllDevices()
     finished();
 }
 
-void KioKdeconnect::listDevice()
+void KioKdeconnect::listDevice(const QString& device)
 {
     infoMessage(i18n("Accessing device..."));
 
-    qCDebug(KDECONNECT_KIO) << "ListDevice" << m_currentDevice;
+    qCDebug(KDECONNECT_KIO) << "ListDevice" << device;
 
-    SftpDbusInterface interface(m_currentDevice);
+    SftpDbusInterface interface(device);
 
     QDBusReply<bool> mountreply = interface.mountAndWait();
 
@@ -177,58 +187,49 @@ void KioKdeconnect::listDevice()
 
 
 
-void KioKdeconnect::listDir(const QUrl &url)
+void KioKdeconnect::listDir(const QUrl& url)
 {
     qCDebug(KDECONNECT_KIO) << "Listing..." << url;
 
-    /// Url is not used here because all we could care about the url is the host, and that's already
-    /// handled in @p setHost
-    Q_UNUSED(url);
-
     if (!m_dbusInterface->isValid()) {
         infoMessage(i18n("Could not contact background service."));
         finished();
         return;
     }
 
-    if (m_currentDevice.isEmpty()) {
+    QString currentDevice = url.host();
+
+    if (currentDevice.isEmpty()) {
         listAllDevices();
     } else {
-        listDevice();
+        listDevice(currentDevice);
     }
 }
 
-void KioKdeconnect::stat(const QUrl &url)
+void KioKdeconnect::stat(const QUrl& url)
 {
     qCDebug(KDECONNECT_KIO) << "Stat: " << url;
 
     KIO::UDSEntry entry;
     entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
+
+    QString currentDevice = url.host();
+    if (!currentDevice.isEmpty()) {
+        SftpDbusInterface interface(currentDevice);
+        entry.insert(KIO::UDSEntry::UDS_LOCAL_PATH, interface.mountPoint());
+    }
+
     statEntry(entry);
 
     finished();
 }
 
-void KioKdeconnect::get(const QUrl &url)
+void KioKdeconnect::get(const QUrl& url)
 {
     qCDebug(KDECONNECT_KIO) << "Get: " << url;
     mimeType(QLatin1String(""));
     finished();
 }
 
-void KioKdeconnect::setHost(const QString &hostName, quint16 port, const QString &user, const QString &pass)
-{
-
-    //This is called before everything else to set the file we want to show
-
-    qCDebug(KDECONNECT_KIO) << "Setting host: " << hostName;
-
-    // In this kio only the hostname is used
-    Q_UNUSED(port)
-    Q_UNUSED(user)
-    Q_UNUSED(pass)
-
-    m_currentDevice = hostName;
-
-}
-
+//needed for JSON file embedding
+#include "kiokdeconnect.moc"
